@@ -8,7 +8,7 @@ require Exporter;
 use warnings;
 use strict;
 use Carp;
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 require XSLoader;
 XSLoader::load ('Image::PNG::QRCode', $VERSION);
 
@@ -60,6 +60,12 @@ sub qrpng
 	    croak "Bad level number $options{level}: use integer between one and four";
 	}
     }
+    if ($options{size}) {
+	if (ref $options{size} ne 'SCALAR') {
+	    carp "size option requires a scalar reference";
+	    delete $options{size};
+	}
+    }
     my $r = defined wantarray () && ! wantarray ();
     my $s = $options{out} && ref $options{out} eq 'SCALAR';
     if ($r || $s) {
